@@ -16,13 +16,12 @@ def cli(ctx: Context, version: bool = False):
     """OpenAPI CLI tool."""
 
     if version:
-        echo(f"{get_version("openapi-cli")}")
+        echo(f"{get_version('openapi-cli')}")
         return
 
     ctx.obj = CliConfig.load()
 
-    module_err = (
-        f"Use `{ctx.info_name} configure client` to set the client module first!" | red)
+    module_err = f"Use `{ctx.info_name} configure client` to set the client module first!" | red
 
     if ctx.obj.client_module_name is None and ctx.invoked_subcommand != "configure":
         raise click.UsageError(module_err)
